==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/ucolorspec_8h.js <==
var ucolorspec_8h =
[
    [ "ColorSpec", "namespaceSteinberg.html#a5b13d028fba1eee386ec9ac208c6238d", null ],
    [ "ColorComponent", "namespaceSteinberg.html#af1189c83b63820c6ccc3167402601fea", null ],
    [ "UColorSpec", "namespaceSteinberg.html#a87699df6cd24276f34afea51d903c6e4", null ],
    [ "UColorComponent", "namespaceSteinberg.html#a3c4f7362f2f494a4120d7c864dd0822d", null ],
    [ "StandardColor", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cd", [
      [ "kBlack", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda84bb4627f551fc5ff2d9aedb8f3b4947", null ],
      [ "kWhite", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda9e1b2d3dcb56c17a372440853228ad01", null ],
      [ "kGray5", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda02a9193b86afaccf9bbf742a323100be", null ],
      [ "kGray10", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda071b3be3908931dc26e8743b00ffde8d", null ],
      [ "kGray20", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1e226959be1359aaaa71395aa86f8208", null ],
      [ "kGray30", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5ff656d817dae9754566238d59d39157", null ],
      [ "kGray40", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda8bdc572a21805c3161278f91a3530712", null ],
      [ "kGray50", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda9db2b60f76d6b83e56c35985b4b9205c", null ],
      [ "kGray60", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdadab15681c7200799430d2f338d0ed61e", null ],
      [ "kGray70", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda0354ed8af3577ebdf208137b26843594", null ],
      [ "kGray80", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1928cdb81e838319f6953a0c49d64c28", null ],
      [ "kGray90", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda63b585983725a29a14552acb823a2949", null ],
      [ "kRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5a655b1a02e5b0311571ca57ce4f3900", null ],
      [ "kLtRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaa03531f6aa4608be014e3f8a8112f49d", null ],
      [ "kDkRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda56b755177db5009ab61067b96229a9be", null ],
      [ "kGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda8ea4b941d1d41f4bd88387c38e13e9d3", null ],
      [ "kLtGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac772acbace7fe195180ec04b0db54e3d", null ],
      [ "kDkGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdad38f804f1c4b123fe442f81576461515", null ],
      [ "kBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaab48c32302f7159d81e081c41dc2d3d2", null ],
      [ "kLtBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda133f1956c6567e805341ce1753a03d28", null ],
      [ "kDkBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda6837b9736b787405dbed0a9d532eaf90", null ],
      [ "kMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda951e8c9c29427097fd137e19a3300e03", null ],
      [ "kLtMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda96ec73e5e8ede13098c92ca3b14c7c43", null ],
      [ "kDkMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1c83f6d971da4f2cb0a97fe97d1f34b5", null ],
      [ "kYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac05df1f876c243e8f60ea03a9f866b80", null ],
      [ "kLtYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdae22e7268faee0570b14aa13c801fa3b9", null ],
      [ "kDkYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda4943112719ee8d66b8de5b8f88ccd8ce", null ],
      [ "kOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda6ad203278f32dfcc959be28888e52582", null ],
      [ "kLtOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaf35707aff5cbf5d69b5f0aecd302d9b1", null ],
      [ "kDkOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5fe89a70ee7bcac01feb5fc1de15985f", null ],
      [ "kGold", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda14ef40d42e6bb88349bc9ad97aed7bdb", null ],
      [ "kBlack50", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda186d906a7af8fff76bff867913a7969f", null ],
      [ "kBlack70", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda64b4e2e55e8f2bd3d9759ad520723121", null ],
      [ "kNumStandardColors", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda020c41a39f7c676ecb89ee23885070b6", null ],
      [ "kLtGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac4512c2e2b20209b3fa8364b8be3483d", null ],
      [ "kGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1ab75347fd43308dc34268db5a181108", null ],
      [ "kDkGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda78c5cc590de98a677b2dc3076c904128", null ]
    ] ],
    [ "MakeColorSpec", "namespaceSteinberg.html#a58b97116e0faaf335c798a65b687e9f2", null ],
    [ "MakeColorSpec", "namespaceSteinberg.html#aa7cb190cb494b7f61aaacf170d322d30", null ],
    [ "GetBlue", "namespaceSteinberg.html#a25a9f00585fee6f2dda46514bb29b933", null ],
    [ "GetGreen", "namespaceSteinberg.html#a7daea0aeaaf968f0cbc3473815ef4c4c", null ],
    [ "GetRed", "namespaceSteinberg.html#a7deed6801721823ffd280717b6675c48", null ],
    [ "GetAlpha", "namespaceSteinberg.html#a7ef9ebfedc0532d783ae68dbbe8f08c7", null ],
    [ "SetBlue", "namespaceSteinberg.html#a145379c6e26917acaa0bac72b8c0bc05", null ],
    [ "SetGreen", "namespaceSteinberg.html#ae8f11c779bd10486d527d1a7142d8e6b", null ],
    [ "SetRed", "namespaceSteinberg.html#a69a06ce98bc91e355a0b3f558344b0f2", null ],
    [ "SetAlpha", "namespaceSteinberg.html#aabd2ebacd043630aac6ea6383bace10b", null ],
    [ "NormalizeColorComponent", "namespaceSteinberg.html#aa50131d71c879a95dfa3efac24b815c6", null ],
    [ "DenormalizeColorComponent", "namespaceSteinberg.html#abad8045987a3d33b9421e724c06a9d6f", null ],
    [ "SetAlphaNorm", "namespaceSteinberg.html#a272ecb0af547f0b5e960144874fc8027", null ],
    [ "GetAlphaNorm", "namespaceSteinberg.html#a572daddd6ee8f61011dcd066eef99b0c", null ],
    [ "NormalizeAlpha", "namespaceSteinberg.html#a170abdd6288ad80f6ddca3d7e9c3fb59", null ],
    [ "DenormalizeAlpha", "namespaceSteinberg.html#abfe74133ed684fa31c7227a9d1a4b3ce", null ],
    [ "StripAlpha", "namespaceSteinberg.html#a27f6f9da6429b67343a7e36078494bd9", null ],
    [ "BlendColor", "namespaceSteinberg.html#a82f9ae0460c5ad8b348cdfa75fec5c68", null ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/ucolorspec_8h.js <==
var ucolorspec_8h =
[
    [ "ColorSpec", "group__smtgtypedef.html#ga5b13d028fba1eee386ec9ac208c6238d", null ],
    [ "ColorComponent", "group__smtgtypedef.html#gaf1189c83b63820c6ccc3167402601fea", null ],
    [ "UColorSpec", "group__smtgtypedef.html#ga87699df6cd24276f34afea51d903c6e4", null ],
    [ "UColorComponent", "group__smtgtypedef.html#ga3c4f7362f2f494a4120d7c864dd0822d", null ],
    [ "StandardColor", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cd", [
      [ "kBlack", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda84bb4627f551fc5ff2d9aedb8f3b4947", null ],
      [ "kWhite", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda9e1b2d3dcb56c17a372440853228ad01", null ],
      [ "kGray5", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda02a9193b86afaccf9bbf742a323100be", null ],
      [ "kGray10", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda071b3be3908931dc26e8743b00ffde8d", null ],
      [ "kGray20", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1e226959be1359aaaa71395aa86f8208", null ],
      [ "kGray30", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5ff656d817dae9754566238d59d39157", null ],
      [ "kGray40", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda8bdc572a21805c3161278f91a3530712", null ],
      [ "kGray50", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda9db2b60f76d6b83e56c35985b4b9205c", null ],
      [ "kGray60", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdadab15681c7200799430d2f338d0ed61e", null ],
      [ "kGray70", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda0354ed8af3577ebdf208137b26843594", null ],
      [ "kGray80", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1928cdb81e838319f6953a0c49d64c28", null ],
      [ "kGray90", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda63b585983725a29a14552acb823a2949", null ],
      [ "kRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5a655b1a02e5b0311571ca57ce4f3900", null ],
      [ "kLtRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaa03531f6aa4608be014e3f8a8112f49d", null ],
      [ "kDkRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda56b755177db5009ab61067b96229a9be", null ],
      [ "kGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda8ea4b941d1d41f4bd88387c38e13e9d3", null ],
      [ "kLtGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac772acbace7fe195180ec04b0db54e3d", null ],
      [ "kDkGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdad38f804f1c4b123fe442f81576461515", null ],
      [ "kBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaab48c32302f7159d81e081c41dc2d3d2", null ],
      [ "kLtBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda133f1956c6567e805341ce1753a03d28", null ],
      [ "kDkBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda6837b9736b787405dbed0a9d532eaf90", null ],
      [ "kMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda951e8c9c29427097fd137e19a3300e03", null ],
      [ "kLtMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda96ec73e5e8ede13098c92ca3b14c7c43", null ],
      [ "kDkMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1c83f6d971da4f2cb0a97fe97d1f34b5", null ],
      [ "kYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac05df1f876c243e8f60ea03a9f866b80", null ],
      [ "kLtYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdae22e7268faee0570b14aa13c801fa3b9", null ],
      [ "kDkYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda4943112719ee8d66b8de5b8f88ccd8ce", null ],
      [ "kOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda6ad203278f32dfcc959be28888e52582", null ],
      [ "kLtOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaf35707aff5cbf5d69b5f0aecd302d9b1", null ],
      [ "kDkOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5fe89a70ee7bcac01feb5fc1de15985f", null ],
      [ "kGold", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda14ef40d42e6bb88349bc9ad97aed7bdb", null ],
      [ "kBlack50", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda186d906a7af8fff76bff867913a7969f", null ],
      [ "kBlack70", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda64b4e2e55e8f2bd3d9759ad520723121", null ],
      [ "kNumStandardColors", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda020c41a39f7c676ecb89ee23885070b6", null ],
      [ "kLtGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac4512c2e2b20209b3fa8364b8be3483d", null ],
      [ "kGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1ab75347fd43308dc34268db5a181108", null ],
      [ "kDkGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda78c5cc590de98a677b2dc3076c904128", null ]
    ] ],
    [ "MakeColorSpec", "namespaceSteinberg.html#a58b97116e0faaf335c798a65b687e9f2", null ],
    [ "MakeColorSpec", "namespaceSteinberg.html#aa7cb190cb494b7f61aaacf170d322d30", null ],
    [ "GetBlue", "namespaceSteinberg.html#a25a9f00585fee6f2dda46514bb29b933", null ],
    [ "GetGreen", "namespaceSteinberg.html#a7daea0aeaaf968f0cbc3473815ef4c4c", null ],
    [ "GetRed", "namespaceSteinberg.html#a7deed6801721823ffd280717b6675c48", null ],
    [ "GetAlpha", "namespaceSteinberg.html#a7ef9ebfedc0532d783ae68dbbe8f08c7", null ],
    [ "SetBlue", "namespaceSteinberg.html#a145379c6e26917acaa0bac72b8c0bc05", null ],
    [ "SetGreen", "namespaceSteinberg.html#ae8f11c779bd10486d527d1a7142d8e6b", null ],
    [ "SetRed", "namespaceSteinberg.html#a69a06ce98bc91e355a0b3f558344b0f2", null ],
    [ "SetAlpha", "namespaceSteinberg.html#aabd2ebacd043630aac6ea6383bace10b", null ],
    [ "NormalizeColorComponent", "namespaceSteinberg.html#aa50131d71c879a95dfa3efac24b815c6", null ],
    [ "DenormalizeColorComponent", "namespaceSteinberg.html#abad8045987a3d33b9421e724c06a9d6f", null ],
    [ "SetAlphaNorm", "namespaceSteinberg.html#a272ecb0af547f0b5e960144874fc8027", null ],
    [ "GetAlphaNorm", "namespaceSteinberg.html#a572daddd6ee8f61011dcd066eef99b0c", null ],
    [ "NormalizeAlpha", "namespaceSteinberg.html#a170abdd6288ad80f6ddca3d7e9c3fb59", null ],
    [ "DenormalizeAlpha", "namespaceSteinberg.html#abfe74133ed684fa31c7227a9d1a4b3ce", null ],
    [ "StripAlpha", "namespaceSteinberg.html#a27f6f9da6429b67343a7e36078494bd9", null ],
    [ "BlendColor", "namespaceSteinberg.html#a82f9ae0460c5ad8b348cdfa75fec5c68", null ]
];
